From: Jeff Kirsher <jeffrey.t.kirsher@intel.com>
To: davem@davemloft.net
Cc: netdev@vger.kernel.org, gospo@redhat.com,
Alexander Duyck <alexander.h.duyck@intel.com>,
Jeff Kirsher <jeffrey.t.kirsher@intel.com>
Subject: [PATCH 3/5] igb: increase delay for copper link setup
Date: Tue, 31 Mar 2009 23:38:38 -0700 [thread overview]
Message-ID: <20090401063837.3046.221.stgit@lost.foo-projects.org> (raw)
In-Reply-To: <20090401063759.3046.89960.stgit@lost.foo-projects.org>
From: Alexander Duyck <alexander.h.duyck@intel.com>
Increase the delay for copper phy init from 15ms to 100ms. This is to
address issues seen in which ethtool -t was failing in some cases on 82576
based adapters.
Signed-off-by: Alexander Duyck <alexander.h.duyck@intel.com>
Signed-off-by: Jeff Kirsher <jeffrey.t.kirsher@intel.com>
---
drivers/net/igb/e1000_phy.c | 7 +++++--
1 files changed, 5 insertions(+), 2 deletions(-)
diff --git a/drivers/net/igb/e1000_phy.c b/drivers/net/igb/e1000_phy.c
index de2d486..f50fac2 100644
--- a/drivers/net/igb/e1000_phy.c
+++ b/drivers/net/igb/e1000_phy.c
@@ -448,8 +448,11 @@ s32 igb_copper_link_setup_igp(struct e1000_hw *hw)
goto out;
}
- /* Wait 15ms for MAC to configure PHY from NVM settings. */
- msleep(15);
+ /*
+ * Wait 100ms for MAC to configure PHY from NVM settings, to avoid
+ * timeout issues when LFS is enabled.
+ */
+ msleep(100);
/*
* The NVM settings will configure LPLU in D3 for
next prev parent reply other threads:[~2009-04-01 6:38 UTC|newest]
Thread overview: 8+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-04-01 6:38 [PATCH 1/5] igb: add support for x2 link width configurations Jeff Kirsher
2009-04-01 6:38 ` [PATCH 2/5] igb: set num_rx/tx_queues to 0 when queues are freed Jeff Kirsher
2009-04-02 7:59 ` David Miller
2009-04-01 6:38 ` Jeff Kirsher [this message]
2009-04-02 8:00 ` [PATCH 3/5] igb: increase delay for copper link setup David Miller
2009-04-01 6:38 ` [PATCH 4/5] igb: cleanup igb loopback path Jeff Kirsher
2009-04-02 8:00 ` David Miller
2009-04-02 7:59 ` [PATCH 1/5] igb: add support for x2 link width configurations David Miller
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090401063837.3046.221.stgit@lost.foo-projects.org \
--to=jeffrey.t.kirsher@intel.com \
--cc=alexander.h.duyck@intel.com \
--cc=davem@davemloft.net \
--cc=gospo@redhat.com \
--cc=netdev@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.